==> amarok-2.9.70_pre20190111.tar.xz: amarok-2.9.70_pre20190111/src/importers/fastforward/FastForwardManager.cpp <==
/****************************************************************************************
 * Copyright (c) 2013 Konrad Zemek <konrad.zemek@gmail.com>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "importers/SimpleImporterManager.h"

#include "FastForwardConfigWidget.h"
#include "FastForwardProvider.h"

AMAROK_EXPORT_SIMPLE_IMPORTER_PLUGIN( FastForwardImporterFactory,
                                      "amarok_importer-fastforward.json",
                                      "FastForwardImporter",
                                      i18n( "Amarok 1.4 (FastForward)" ),
                                      i18n( "Amarok 1.4 Statistics Importer" ),
                                      QIcon::fromTheme( "amarok" ),
                                      StatSyncing::FastForwardConfigWidget,
                                      StatSyncing::FastForwardProvider )

#include <FastForwardManager.moc>

==> amarok-3.0.81.tar.xz: amarok-3.0.81/src/importers/fastforward/FastForwardManager.cpp <==
/****************************************************************************************
 * Copyright (c) 2013 Konrad Zemek <konrad.zemek@gmail.com>                             *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#include "importers/SimpleImporterManager.h"

#include "FastForwardConfigWidget.h"
#include "FastForwardProvider.h"

AMAROK_EXPORT_SIMPLE_IMPORTER_PLUGIN( FastForwardImporterFactory,
                                      "amarok_importer-fastforward.json",
                                      QStringLiteral("FastForwardImporter"),
                                      i18n( "Amarok 1.4 (FastForward)" ),
                                      i18n( "Amarok 1.4 Statistics Importer" ),
                                      QIcon::fromTheme( QStringLiteral("amarok") ),
                                      StatSyncing::FastForwardConfigWidget,
                                      StatSyncing::FastForwardProvider )

#include <FastForwardManager.moc>
